Konfiguration - Testland Infrastruktur
========================

Nachfolgend ein kurzer Überblick zu der von A-SIT verwendeten eIDAS Test-Land Konfiguration auf Basis der eIDAS Node 2.6

## Systemanforderungen
 - Java 11
 - Tomcat 9



## Java Startparameter
Die Konfiguration der einzelnen Komponenten wird via Java SystemD Startparameter übergeben. Nachfolgend findet sich ein Ausszug aus der von uns verwendeten Konfiguration.
```
#### Application specific JAVA Runtime configuration

## Basic config directory
APP_ROOT=/opt/tomcat/eidas_infra
APP_ROOT_CONF=$APP_ROOT/conf

## Logger configuration
LOGS_BASE=-Dlogs.base=$APP_ROOT/logs
LOGGING_OPT=-Dlogback.configurationFile=file:$APP_ROOT_CONF/logback.xml


## eIDAS specific custom security policy
##   It's required because eIDAS Node v2.6 does not register BouncyCastleProvider, but it's needed with software keys
JAVA_SEC="-Djava.security.properties=$APP_ROOT/conf/eidas_java.security --module-path $APP_ROOT/lib/bcprov-jdk15on-1.64.jar --add-modules org.bouncycastle.provider"


## Application configurations  -- Add application configuration here ----
EIDAS_NODE_CONFIG_REP=-DEIDAS_CONFIG_REPOSITORY=$APP_ROOT/conf/eidas/eIDAS_node/
EIDAS_CONN_CONFIG_REP=-DSPECIFIC_CONNECTOR_CONFIG_REPOSITORY=$APP_ROOT/conf/eidas/specificConnector/
EIDAS_PROXY_CONFIG_REP=-DSPECIFIC_PROXY_SERVICE_CONFIG_REPOSITORY=$APP_ROOT/conf/eidas/specificProxyService/
EIDAS_SP=-DSP_CONFIG_REPOSITORY=$APP_ROOT/conf/eidas/sp/
EIDAS_IDP=-DIDP_CONFIG_REPOSITORY=$APP_ROOT/conf/eidas/idp/
APP_CONFIG="$EIDAS_NODE_CONFIG_REP $EIDAS_CONN_CONFIG_REP $EIDAS_PROXY_CONFIG_REP $EIDAS_SP $EIDAS_IDP"


## set full JAVA options
JAVA_OPTS="$JAVA_OPTS $APP_CONFIG $LOGGING_OPT $LOGS_BASE $JAVA_SEC"
```


## Applikationskonfiguration

Die Test-Land Infrastruktur besteht aus mehreren Einzelkomponten. Die nachfolgende Beschreibung definiert jene Dateien welche Minimal angepasst werden müssen.   
Detailierte Informationen zum eIDAS Node selbst finden sich Releasepacket des eIDAS Nodes oder im Release-Packet zum MS-Proxy-Service v1.0.

### eIDAS Node
 - _/eidas/eIDAS_node/eidas.xml_
     - Anpassung der Endpunkte
     - Anpassung des Country-Codes des Testlands. Unsere Konfiguration verwendet aktuell *EE** als Testland
     - Anpassung des eIDAS Proxy-Service
     - Optionale Anpassung der Kontaktdaten in den SAML2 Metadaten
 - _/eidas/eIDAS_node/igniteNode.xml_
 - _/eidas/eIDAS_node/igniteSpecificCommunication.xml_
     - Siehe auch Informationen zur Konfiguration des eIDAS-Nodes enthalten in Release des MS-Proxy-Service v1.0  
 - _/eidas/eIDAS_node/SignModule_Service.xml_
     - KeyStore Konfiguration für eIDAS-Node Proxy-Service
     - Es können sowohl Self-Signed als Schlüsselmaterial aus eine CA erwendet werden
         - **Hinweis:** Der eIDAS Node aus der Referenz-Implementierung der Europäischen Kommission implementiert Validierungen auf Basis des CountryCodes, welcher in den Zertifikaten des eIDAS Nodes verwendet werden. Für die Test-Land Infrastruktur muss somit der CountryCode im Subject der Zertifikate identisch zum Country-Code des Testlands sein.
 - _/eidas/eIDAS_node/SignModule_Connector.xml_
     - KeyStore Konfiguration für eIDAS-Node Connector 
     - Für das Testland kann hier der selbe KeyStore wie für _SignModule_Service.xml_ verwendet werden

### MS-Specific Proxy-Service
 - _/eidas/specificProxyService/specificProxyService.xml_
     - Anpassung der Endpunkte
 - _/eidas/specificProxyService/igniteSpecificCommunication.xml_
     - Siehe auch Informationen zur Konfiguration des eIDAS-Nodes enthalten in Release des MS-Proxy-Service v1.0  

### MS-Specific Connector
 - _/eidas/specificConnector/specificConnector.xml_
     - Anpassung der Endpunkte
 - _/eidas/specificConnector/igniteSpecificCommunication.xml_
     - Siehe auch Informationen zur Konfiguration des eIDAS-Nodes enthalten in Release des MS-Proxy-Service v1.0  

### IDP
 - _/eidas/idp/user.properties_
     - Konfiguration der Test-Benutzer inkl. Attribute

### SP
 - _/eidas/sp/sp.properties_
     - Konfiguration der angebundenen Länder am Test-SP